pub enum BannerError {
BannerFile {
source: BannerImageError,
},
TooManyKeyframes {
max: usize,
actual: usize,
backtrace: Backtrace,
},
VersionNotSupported {
max: BannerVersion,
actual: BannerVersion,
backtrace: Backtrace,
},
}Expand description
Errors related to Banner.
Variants
BannerFile
See BannerImageError.
Fields

source: BannerImageErrorSource error.
TooManyKeyframes
Occurs when trying to build a banner to place in the ROM, but there were too many keyframes.
Fields
VersionNotSupported
Occurs when trying to build a banner to place in the ROM, but the version is not yet supported by this library.