pub enum LogoError {
InvalidHeader {
expected: u32,
actual: u32,
backtrace: Backtrace,
},
InvalidFooter {
expected: u32,
actual: u32,
backtrace: Backtrace,
},
WrongSize {
expected: usize,
actual: usize,
backtrace: Backtrace,
},
}Expand description
Errors related to Logo.
Variants
InvalidHeader
Occurs when decompressing a logo with an invalid header.
Fields
Occurs when decompressing a logo with an invalid footer.
WrongSize
Occurs when decompressing a logo which doesn’t yield the correct bitmap size.