pub enum LogoLoadError {
Io {
source: Error,
},
Image {
source: ImageError,
},
InvalidColor {
x: u32,
y: u32,
backtrace: Backtrace,
},
ImageSize {
expected: ImageSize,
actual: ImageSize,
backtrace: Backtrace,
},
}Expand description
Errors when loading a Logo.
Variants
Io
See io::Error.
Image
See ImageError.
Fields

source: ImageErrorSource error.
InvalidColor
Occurs when the input image has a pixel which isn’t white or black.
Fields
ImageSize
Occurs when the input image has the wrong size.