pub enum OverlayError {
RawHeader {
source: RawHeaderError,
},
RawFat {
source: RawFatError,
},
Arm9OverlaySignatures {
source: Arm9OverlaySignaturesError,
},
NoOverlaySignatures {
backtrace: Backtrace,
},
SignedArm7Overlay {
backtrace: Backtrace,
},
OverlayCompression {
backtrace: Backtrace,
},
}Expand description
Errors related to Overlay.
Variants
RawHeader
See RawHeaderError.
Fields

source: RawHeaderErrorSource error.
RawFat
See RawFatError.
Fields

source: RawFatErrorSource error.
Arm9OverlaySignatures
Fields

source: Arm9OverlaySignaturesErrorSource error.
NoOverlaySignatures
Occurs when there are no overlay signatures in the ARM9 program.
SignedArm7Overlay
Occurs when trying to create a signed ARM7 overlay, but signing ARM7 overlays is not supported.
OverlayCompression
Occurs when trying to compute the signature but the overlay is not in its originally compressed state.