RomSaveError

Enum RomSaveError 

pub enum RomSaveError {
Show 18 variants BlowfishKeyNeeded, Io { source: Error, }, File { source: FileError, }, SerdeSaphyrDeserialize { source: Error, }, SerdeSaphyrSerialize { source: Error, }, LogoSave { source: LogoSaveError, }, LogoLoad { source: LogoLoadError, }, RawBuildInfo { source: RawBuildInfoError, }, Arm9 { source: Arm9Error, }, Arm9Autoload { source: Arm9AutoloadError, }, BannerImage { source: BannerImageError, }, Lz77Decompress { source: Lz77DecompressError, }, Overlay { source: OverlayError, }, HmacSha1FromBytes { source: HmacSha1FromBytesError, }, Arm9HmacSha1Key { source: Arm9HmacSha1KeyError, }, Arm9OverlaySignatures { source: Arm9OverlaySignaturesError, }, NoHmacSha1Key { backtrace: Backtrace, }, AutoloadNotFound { index: u32, backtrace: Backtrace, },
}
Errors related to Rom::save and Rom::load.

Variants



BlowfishKeyNeeded

Occurs when the ROM is encrypted but no Blowfish key was provided.



Io

See io::Error.

Fields

source: Error

Source error.



File

See [FileError].

Fields

source: FileError

Source error.



SerdeSaphyrDeserialize

Fields

source: Error

Source error.



SerdeSaphyrSerialize

Fields

source: Error

Source error.



LogoSave

Fields

source: LogoSaveError

Source error.



LogoLoad

Fields

source: LogoLoadError

Source error.



RawBuildInfo

Fields

source: RawBuildInfoError

Source error.



Arm9

See Arm9Error.

Fields

source: Arm9Error

Source error.



Arm9Autoload

Fields

source: Arm9AutoloadError

Source error.



BannerImage

Fields

source: BannerImageError

Source error.



Lz77Decompress

Fields

source: Lz77DecompressError

Source error.



Overlay

Fields

source: OverlayError

Source error.



HmacSha1FromBytes

Fields

source: HmacSha1FromBytesError

Source error.



Arm9HmacSha1Key

Fields

source: Arm9HmacSha1KeyError

Source error.



Arm9OverlaySignatures

Fields

source: Arm9OverlaySignaturesError

Source error.



NoHmacSha1Key

Occurs when the HMAC-SHA1 key was not provided for a signed overlay.

Fields

backtrace: Backtrace

Backtrace to the source of the error.



AutoloadNotFound

Occurs when an autoload was not found in the config.

Fields

index: u32

The index of the autoload that was missing.

backtrace: Backtrace

Backtrace to the source of the error.