pub enum Arm9FooterError {
RawHeader {
source: RawHeaderError,
},
WrongSize {
expected: usize,
actual: usize,
backtrace: Backtrace,
},
Misaligned {
expected: usize,
actual: usize,
backtrace: Backtrace,
},
NoNitrocode {
expected: u32,
actual: u32,
backtrace: Backtrace,
},
}Expand description
Errors related to Arm9Footer.
Variants
RawHeader
See RawHeaderError.
Fields

source: RawHeaderErrorSource error.
WrongSize
Occurs when the given input is not the expected size for an ARM9 footer.
Fields
Misaligned
Occurs when the given input less aligned than Arm9Footer.
Fields
NoNitrocode
Occurs when nitrocode was not found in the input.