pub enum AutoloadKind {
Itcm,
Dtcm,
Unknown(u32),
}Expand description
Autoload kind.
Variants
Itcm
Instruction TCM (Tightly Coupled Memory). Mainly used to make functions have fast and predictable load times.
Dtcm
Data TCM (Tightly Coupled Memory). Mainly used to make data have fast and predictable access times.
Unknown(u32)
Other autoload block of unknown purpose.