pub enum HmacSha1SignatureError {
InvalidSize {
backtrace: Backtrace,
},
Misaligned {
expected: usize,
actual: usize,
backtrace: Backtrace,
},
}Expand description
Errors related to HmacSha1Signature.
Variants
InvalidSize
Occurs when the input is not evenly divisible into a slice of HmacSha1Signature.
Misaligned
Occurs when the input is less aligned than HmacSha1Signature.