pub enum RawAutoloadInfoError {
RawBuildInfo {
source: RawBuildInfoError,
},
InvalidSize {
backtrace: Backtrace,
},
Misaligned {
expected: usize,
actual: usize,
backtrace: Backtrace,
},
}Expand description
Errors related to AutoloadInfo.
Variants
RawBuildInfo
See RawBuildInfoError.
Fields

source: RawBuildInfoErrorSource error.
InvalidSize
Occurs when the input is not evenly divisible into a slice of AutoloadInfo.
Misaligned
Occurs when the input is less aligned than AutoloadInfo.