pub enum RawBannerError {
RawHeader {
source: RawHeaderError,
},
UnknownVersion {
version: u16,
backtrace: Backtrace,
},
InvalidSize {
version: u16,
expected: usize,
actual: usize,
backtrace: Backtrace,
},
Misaligned {
expected: usize,
actual: usize,
backtrace: Backtrace,
},
}Expand description
Errors related to Banner.
Variants
RawHeader
See RawHeaderError.
Fields

source: RawHeaderErrorSource error.
UnknownVersion
Occurs when the input banner has an unknown version. Should not occur unless there’s an undocumented banner version we’re unaware of.
InvalidSize
Occurs when the input is not the right size according to its version number.
Fields
Misaligned
Occurs when the input is less aligned than the banner