pub enum RawFatError {
RawHeader {
source: RawHeaderError,
},
InvalidSize {
backtrace: Backtrace,
},
Misaligned {
expected: usize,
actual: usize,
backtrace: Backtrace,
},
}Expand description
Errors related to FileAlloc.
Variants
RawHeader
See RawHeaderError.
Fields

source: RawHeaderErrorSource error.
InvalidSize
Occurs when the input is not evenly divisible into a slice of FileAlloc.
Misaligned
Occurs when the input is less aligned than FileAlloc.