Enum ds_rom::rom::raw::RawHeaderError
source · pub enum RawHeaderError {
DataTooSmall {
expected: usize,
actual: usize,
backtrace: Backtrace,
},
Misaligned {
expected: usize,
actual: usize,
backtrace: Backtrace,
},
}Expand description
Errors related to Header.
Variants
DataTooSmall
Occurs when the input is too small to contain a header.
Fields
Misaligned
Occurs when the input is less aligned than Header.