pub enum RawMultibootSignatureError {
RawHeader {
source: RawHeaderError,
},
DataTooSmall {
expected: usize,
actual: usize,
backtrace: Backtrace,
},
Misaligned {
expected: usize,
actual: usize,
backtrace: Backtrace,
},
InvalidMagic {
expected: u32,
actual: u32,
backtrace: Backtrace,
},
}Expand description
Errors related to MultibootSignature.
Variants
RawHeader
See RawHeaderError.
Fields

source: RawHeaderErrorSource error.
DataTooSmall
Occurs when the input is too small to contain a MultibootSignature.
Fields
Misaligned
Occurs when the input is less aligned than MultibootSignature.
Fields
InvalidMagic
Occurs when the magic number does not match MULTIBOOT_SIGNATURE_MAGIC.