pub enum RawOverlayError {
RawHeader {
source: RawHeaderError,
},
RawArm9 {
source: RawArm9Error,
},
Arm9OverlaySignatures {
source: Arm9OverlaySignaturesError,
},
InvalidSize {
backtrace: Backtrace,
},
Misaligned {
expected: usize,
actual: usize,
backtrace: Backtrace,
},
}Expand description
Errors related to Overlay.
Variants
RawHeader
See RawHeaderError.
Fields

source: RawHeaderErrorSource error.
RawArm9
See RawHeaderError.
Fields

source: RawArm9ErrorSource error.
Arm9OverlaySignatures
Fields

source: Arm9OverlaySignaturesErrorSource error.
InvalidSize
Occurs when the input is not evenly divisible into a slice of Overlay.
Misaligned
Occurs when the input is less aligned than Overlay.