Banner

Struct Banner 

pub struct Banner<'a> { /* private fields */ }
Banner for displaying an icon and title on the home menu. This is the raw struct, see the plain one here.

Implementations

Source

impl<'a> Banner<'a>

pub fn new(version: BannerVersion) -> Self

Creates a new Banner.

pub fn borrow_from_slice(data: &'a [u8]) -> Result<Self, RawBannerError>

Reinterprets a &[u8] as a reference to Banner.

Errors

This function will return an error if the input has an unknown banner version, or has the wrong size for its version, or is not aligned enough.

pub fn version(&self) -> BannerVersion

Returns the version of this Banner.

pub fn crc(&self, index: usize) -> u16

Returns the CRC checksum at the given index.

pub fn crc_mut(&mut self, index: usize) -> &mut u16

Returns a mutable CRC checksum at the given index.

pub fn bitmap(&self) -> &BannerBitmap

Returns a reference to the bitmap of this Banner.

pub fn bitmap_mut(&mut self) -> &mut BannerBitmap

Returns a mutable reference to the bitmap of this Banner.

pub fn palette(&self) -> &BannerPalette

Returns a reference to the palette of this Banner.

pub fn palette_mut(&mut self) -> &mut BannerPalette

Returns a mutable reference to the palette of this Banner.

pub fn title(&self, language: Language) -> Option<&Unicode16Array<0x80>>

Returns a title for the given language, or None the language is not supported by this banner version.

pub fn title_mut( &mut self, language: Language, ) -> Option<&mut Unicode16Array<0x80>>

Returns a mutable title for the given language, or None the language is not supported by this banner version.

pub fn animation(&self) -> Option<&BannerAnimation>

Returns a reference to the animation of this Banner, if it exists in this banner version.

pub fn animation_mut(&mut self) -> Option<&mut BannerAnimation>

Returns a mutable reference to the animation of this Banner, if it exists in this banner version.

pub fn full_data(&self) -> &[u8]

Returns a reference to the full data of this Banner.

pub fn display(&self, indent: usize) -> DisplayBanner<'_>

Creates a DisplayBanner which implements Display.