#[repr(C)]pub struct BuildInfo {
pub autoload_infos_start: u32,
pub autoload_infos_end: u32,
pub autoload_blocks: u32,
pub bss_start: u32,
pub bss_end: u32,
pub compressed_code_end: u32,
pub sdk_version: u32,
/* private fields */
}Expand description
Build info for the ARM9 module. This is the raw version, see the plain one here.
Fields
autoload_infos_start: u32Offset to the start of super::AutoloadInfos.
autoload_infos_end: u32Offset to the end of super::AutoloadInfos.
autoload_blocks: u32Offset to where the autoload blocks start.
bss_start: u32Offset to the start of uninitialized data in this module.
bss_end: u32Offset to the end of uninitialized data in this module.
compressed_code_end: u32Size of this module after compression.
sdk_version: u32SDK version? Value is higher for newer games, but it’s unclear what this value is for.
Implementations
sourceimpl BuildInfo
impl BuildInfo
sourcepub fn borrow_from_slice(data: &[u8]) -> Result<&Self, RawBuildInfoError>
pub fn borrow_from_slice(data: &[u8]) -> Result<&Self, RawBuildInfoError>
sourcepub fn borrow_from_slice_mut(
data: &mut [u8],
) -> Result<&mut Self, RawBuildInfoError>
pub fn borrow_from_slice_mut( data: &mut [u8], ) -> Result<&mut Self, RawBuildInfoError>
sourcepub fn is_compressed(&self) -> bool
pub fn is_compressed(&self) -> bool
Returns whether this BuildInfo is compressed.
sourcepub fn display(&self, indent: usize) -> DisplayBuildInfo<'_>
pub fn display(&self, indent: usize) -> DisplayBuildInfo<'_>
Creates a DisplayBuildInfo which implements Display.