Struct ds_rom::rom::raw::FileAlloc

source ·
#[repr(C)]
pub struct FileAlloc { pub start: u32, pub end: u32, }
A file allocation which tells where a file starts and ends in the ROM.

Fields

start: u32

Start offset.

end: u32

End offset.

Implementations

source

impl FileAlloc

source

pub fn borrow_from_slice(data: &[u8]) -> Result<&[Self], RawFatError>

Reinterprets a &[u8] as a reference to FileAlloc.

Errors

This function will return an error if the input the wrong size or not aligned enough.

source

pub fn into_file(self, rom: &[u8]) -> &[u8]

Returns the contents of this file taken directly from the ROM.

source

pub fn range(self) -> Range<usize>

Returns a ROM offset Range for this file.