Fnt

Struct Fnt 

pub struct Fnt<'a> {
    pub subtables: Box<[FntSubtable<'a>]>,
}
File Name Table or FNT for short. Contains the names of every file and directory in the ROM. This is the raw struct, see the plain one here.

Fields

subtables: Box<[FntSubtable<'a>]>

Every directory has one subtable, indexed by dir_id & 0xfff

Implementations

Source

impl<'a> Fnt<'a>

pub fn borrow_from_slice(data: &'a [u8]) -> Result<Self, RawFntError>

Reinterprets a &[u8] as an Fnt.

Errors

This function will return an error if the input is too small or not aligned enough.

pub fn build(self) -> Result<Box<[u8]>, Error>

Builds the FNT to be placed in a ROM.

Errors

This function will return an error if an I/O operation fails.