MultibootSignature

Struct MultibootSignature 

pub struct MultibootSignature { /* private fields */ }
Contains the RSA signature used to verify the integrity of the ROM header and the ARM9 and ARM7 programs, after it is transferred for Download Play.

Implementations

Source

impl MultibootSignature

pub fn borrow_from_slice( data: &[u8], ) -> Result<&Self, RawMultibootSignatureError>

Reinterprets a &[u8] as a reference to MultibootSignature.

Errors

This function will return an error if the input is too small or not aligned enough.

pub fn display(&self, indent: usize) -> DisplayMultibootSignature<'_>

Creates a DisplayMultibootSignature which implements Display.

pub fn magic(&self) -> u32

Returns the magic number of this MultibootSignature. This is always equal to MULTIBOOT_SIGNATURE_MAGIC.

pub fn rsa_signature(&self) -> &RsaSignature

Returns the RsaSignature of this MultibootSignature.

pub fn key_seed(&self) -> u32

Returns the RSA key seed of this MultibootSignature.