Overlay

Struct Overlay 

#[repr(C)]
pub struct Overlay { pub id: u32, pub base_addr: u32, pub code_size: u32, pub bss_size: u32, pub ctor_start: u32, pub ctor_end: u32, pub file_id: u32, pub flags: OverlayFlags, }
An entry in an overlay table. This is the raw struct, see the plain one here.

Fields

id: u32

Overlay ID.

base_addr: u32

Base address.

code_size: u32

Initialized size.

bss_size: u32

Uninitialized size.

ctor_start: u32

Offset to start of .ctor section.

ctor_end: u32

Offset to end of .ctor section.

file_id: u32

File ID for the FAT.

flags: OverlayFlags

Flags and compressed size.

Implementations

Source

impl Overlay

pub fn borrow_from_slice(data: &[u8]) -> Result<&[Self], RawOverlayError>

Reinterprets a &[u8] as a reference to Overlay.

Errors

This function will return an error if the input is the wrong size, or not aligned enough.

pub fn display(&self, indent: usize) -> DisplayOverlay<'_>

Creates a DisplayOverlay which implements Display.