pub struct OverlayTable<'a> { /* private fields */ }Expand description
An overlay table, used for both ARM9 and ARM7 overlays. This is the raw struct, see the plain one here.
Implementations
Sourceimpl<'a> OverlayTable<'a>
impl<'a> OverlayTable<'a>
Sourcepub fn new<O>(overlays: O, signature: Option<HmacSha1Signature>) -> Self
pub fn new<O>(overlays: O, signature: Option<HmacSha1Signature>) -> Self
Creates a new overlay table.
Sourcepub fn compute_signature(&self, hmac_sha1: &HmacSha1) -> HmacSha1Signature
pub fn compute_signature(&self, hmac_sha1: &HmacSha1) -> HmacSha1Signature
Computes the HMAC-SHA1 signature of this overlay table using the given HMAC-SHA1 instance.
Sourcepub fn verify_signature(&self, hmac_sha1: &HmacSha1) -> bool
pub fn verify_signature(&self, hmac_sha1: &HmacSha1) -> bool
Verifies the HMAC-SHA1 signature of this overlay table using the given HMAC-SHA1 instance.
Sourcepub fn signature(&self) -> Option<HmacSha1Signature>
pub fn signature(&self) -> Option<HmacSha1Signature>
Returns the HMAC-SHA1 signature of the overlay table, if it exists.
Sourcepub fn display(&'a self, indent: usize) -> DisplayOverlayTable<'a>
pub fn display(&'a self, indent: usize) -> DisplayOverlayTable<'a>
Returns a DisplayOverlayTable which implements Display.