Arm9

Struct Arm9 

pub struct Arm9<'a> { /* private fields */ }
ARM9 program.

Implementations

Source

impl<'a> Arm9<'a>

pub fn new<T: Into<Cow<'a, [u8]>>>( data: T, offsets: Arm9Offsets, ) -> Result<Self, RawBuildInfoError>

Creates a new ARM9 program from raw data.

pub fn with_two_tcms( data: Vec<u8>, itcm: Autoload<'_>, dtcm: Autoload<'_>, offsets: Arm9Offsets, options: Arm9WithTcmsOptions, ) -> Result<Self, RawBuildInfoError>

Creates a new ARM9 program with raw data and two autoloads (ITCM and DTCM).

Errors

See Self::build_info_mut.

pub fn with_autoloads( data: Vec<u8>, autoloads: &[Autoload<'_>], offsets: Arm9Offsets, options: Arm9WithTcmsOptions, ) -> Result<Self, RawBuildInfoError>

Creates a new ARM9 program with raw data and a list of autoloads.

Errors

See Self::build_info_mut.

pub fn is_encrypted(&self) -> bool

Returns whether the secure area is encrypted. See Self::originally_encrypted for whether the secure area was encrypted originally.

pub fn decrypt( &mut self, key: &BlowfishKey, gamecode: u32, ) -> Result<(), Arm9Error>

Decrypts the secure area. Does nothing if already decrypted.

Errors

This function will return an error if the program is too small to contain a secure area, Blowfish::decrypt fails or “encryObj” was not found.

pub fn encrypt( &mut self, key: &BlowfishKey, gamecode: u32, ) -> Result<(), Arm9Error>

Encrypts the secure area. Does nothing if already encrypted.

Errors

This function will return an error if the program is too small to contain a secure area, or the secure area ID was not found.

pub fn encrypted_secure_area( &self, key: &BlowfishKey, gamecode: u32, ) -> [u8; 16384]

Returns an encrypted copy of the secure area.

pub fn secure_area_crc(&self, key: &BlowfishKey, gamecode: u32) -> u16

Returns a CRC checksum of the encrypted secure area.

pub fn build_info(&self) -> Result<&BuildInfo, RawBuildInfoError>

Returns a reference to the build info.

Errors

See BuildInfo::borrow_from_slice.

pub fn build_info_mut(&mut self) -> Result<&mut BuildInfo, RawBuildInfoError>

Returns a mutable reference to the build info.

Errors

See BuildInfo::borrow_from_slice_mut.

pub fn libraries(&self) -> Result<Box<[LibraryEntry<'_>]>, Utf8Error>

Returns the library version strings in this Arm9.

Errors

This function will return an error if a library string is not valid UTF-8.

pub fn is_compressed(&self) -> Result<bool, RawBuildInfoError>

Returns whether this ARM9 program is compressed. See Self::originally_compressed for whether the program was compressed originally.

Errors

See Self::build_info.

pub fn decompress(&mut self) -> Result<(), Arm9Error>

Decompresses this ARM9 program. Does nothing if already decompressed.

Errors

See Self::is_compressed and Self::build_info_mut.

pub fn compress(&mut self) -> Result<(), Arm9Error>

Compresses this ARM9 program. Does nothing if already compressed.

Errors

See Self::is_compressed, Lz77::compress and Self::build_info_mut.

pub fn autoload_infos(&self) -> Result<Vec<AutoloadInfo>, Arm9AutoloadError>

Returns the autoload infos of this Arm9.

Errors

This function will return an error if Self::build_info or [Self::get_autoload_infos] fails or this ARM9 program is compressed.

pub fn autoloads(&self) -> Result<Box<[Autoload<'_>]>, Arm9AutoloadError>

Returns the autoloads of this Arm9.

Errors

This function will return an error if Self::build_info or [Self::get_autoload_infos] fails or this ARM9 program is compressed.

pub fn num_unknown_autoloads(&self) -> Result<usize, Arm9AutoloadError>

Returns the number of unknown autoloads of this Arm9.

Errors

See Self::autoloads.

pub fn hmac_sha1_key(&self) -> Result<Option<[u8; 64]>, Arm9HmacSha1KeyError>

Returns the HMAC-SHA1 key in this ARM9 program.

pub fn overlay_table_signature( &self, ) -> Result<Option<&HmacSha1Signature>, Arm9OverlaySignaturesError>

Returns the ARM9 overlay table signature.

Errors

This function will return an error if the ARM9 program is compressed or if HmacSha1Signature::borrow_from_slice fails.

pub fn overlay_table_signature_mut( &mut self, ) -> Result<Option<&mut HmacSha1Signature>, Arm9OverlaySignaturesError>

Returns a mutable reference to the ARM9 overlay table signature.

Errors

This function will return an error if the ARM9 program is compressed or if HmacSha1Signature::borrow_from_slice_mut fails.

pub fn overlay_signatures( &self, num_overlays: usize, ) -> Result<Option<&[HmacSha1Signature]>, Arm9OverlaySignaturesError>

Returns the ARM9 overlay signature table.

Errors

This function will return an error if the ARM9 program is compressed or if HmacSha1Signature::borrow_from_slice fails.

pub fn overlay_signatures_mut( &mut self, num_overlays: usize, ) -> Result<Option<&mut [HmacSha1Signature]>, Arm9OverlaySignaturesError>

Returns a mutable reference to the ARM9 overlay signature table.

Errors

This function will return an error if the ARM9 program is compressed or if HmacSha1Signature::borrow_from_slice_mut fails.

pub fn code(&self) -> Result<&[u8], RawBuildInfoError>

Returns the code of this ARM9 program.

Errors

See Self::build_info.

pub fn full_data(&self) -> &[u8]

Returns a reference to the full data.

pub fn base_address(&self) -> u32

Returns the base address.

pub fn end_address(&self) -> Result<u32, RawBuildInfoError>

Returns the end address.

pub fn entry_function(&self) -> u32

Returns the entry function address.

pub fn build_info_offset(&self) -> u32

Returns the build info offset.

pub fn autoload_callback(&self) -> u32

Returns the autoload callback address.

pub fn overlay_signatures_offset(&self) -> u32

Returns the offset to the overlay HMAC-SHA1 signature table.

pub fn bss(&self) -> Result<Range<u32>, RawBuildInfoError>

Returns the Range of uninitialized data in this ARM9 program.

Errors

See Self::build_info.

pub fn offsets(&self) -> &Arm9Offsets

Returns a reference to the ARM9 offsets.

pub fn originally_compressed(&self) -> bool

Returns whether the ARM9 program was compressed originally. See Self::is_compressed for the current state.

pub fn originally_encrypted(&self) -> bool

Returns whether the ARM9 program was encrypted originally. See Self::is_encrypted for the current state.