Struct ds_rom::rom::Autoload

source ·
pub struct Autoload<'a> { /* private fields */ }
An autoload block.

Implementations

source

impl<'a> Autoload<'a>

source

pub fn new<T: Into<Cow<'a, [u8]>>>(data: T, info: AutoloadInfo) -> Self

Creates a new autoload block from raw data.

source

pub fn code(&self) -> &[u8]

Returns a reference to the code of this Autoload.

source

pub fn full_data(&self) -> &[u8]

Returns a reference to the full data of this Autoload.

source

pub fn into_data(self) -> Box<[u8]>

Consumes this Autoload and returns the data.

source

pub fn base_address(&self) -> u32

Returns the base address of this Autoload.

source

pub fn kind(&self) -> AutoloadKind

Returns the kind of this Autoload.

source

pub fn bss_size(&self) -> u32

Returns the size of the uninitialized data of this Autoload.

source

pub fn info(&self) -> &AutoloadInfo

Returns a reference to the info of this Autoload.