Struct Banner

pub struct Banner {
    pub title: BannerTitle,
    pub images: BannerImages,
    pub keyframes: Option<Vec<BannerKeyframe>>,
    /* private fields */
}
ROM banner.

Fields

title: BannerTitle

Game title in different languages.

images: BannerImages

Icon to show on the home screen.

keyframes: Option<Vec<BannerKeyframe>>

Keyframes for animated icons.

Implementations

Source

impl Banner

pub fn load_raw(banner: &Banner<'_>) -> Self

Loads from a raw banner.

pub fn build(&self) -> Result<Banner<'_>, BannerError>

Builds a raw banner to place in a ROM.

Errors

This function will return an error if the banner version is not yet supported by this library, or there are too many keyframes.