BannerImages

Struct BannerImages 

pub struct BannerImages {
    pub bitmap: BannerBitmap,
    pub palette: BannerPalette,
    pub animation_bitmaps: Option<Box<[BannerBitmap]>>,
    pub animation_palettes: Option<Box<[BannerPalette]>>,
    pub bitmap_path: PathBuf,
    pub palette_path: PathBuf,
}
Icon for the Banner.

Fields

bitmap: BannerBitmap

Main bitmap.

palette: BannerPalette

Main palette.

animation_bitmaps: Option<Box<[BannerBitmap]>>

Bitmaps for animated icon.

animation_palettes: Option<Box<[BannerPalette]>>

Palettes for animated icon

bitmap_path: PathBuf

Path to bitmap PNG.

palette_path: PathBuf

Path to palette PNG.

Implementations

Source

impl BannerImages

pub fn from_bitmap(bitmap: BannerBitmap, palette: BannerPalette) -> Self

Creates a new BannerImages from a bitmap and palette.

pub fn load(&mut self, path: &Path) -> Result<(), BannerImageError>

Loads the bitmap and palette

Errors

This function will return an error if [Reader::open] or [Reader::decode] fails, or if the images are the wrong size, or the bitmap has a color not present in the palette.

pub fn save_bitmap_file(&self, path: &Path) -> Result<(), BannerImageError>

Saves to a bitmap and palette file in the given path.

Errors

See [RgbImage::save].