ds_rom::rom

Struct FileSystem

pub struct FileSystem<'a> { /* private fields */ }
Contains files and directories to be placed into a ROM.

Implementations

Source

impl<'a> FileSystem<'a>

pub fn new(num_overlays: usize) -> Self

Creates a new FileSystem. The number of overlays are used to determine the first file ID, since overlays are also located in the FAT but not the FNT.

pub fn load<P: AsRef<Path>>( root: P, num_overlays: usize, ) -> Result<Self, FileError>

Loads a file system from the given root directory. This will traverse and add all folders and files into the FileSystem struct.

Errors

This function will return an error if an I/O operation fails.

pub fn is_dir(id: u16) -> bool

Returns whether the ID is a directory ID.

pub fn is_file(id: u16) -> bool

Returns whether the ID is a file ID.

pub fn name(&self, id: u16) -> &str

Returns the name of a directory or file.

pub fn dir(&self, id: u16) -> &Dir

Returns a directory.

pub fn file(&self, id: u16) -> &File<'_>

Returns a file.

pub fn parse( fnt: &Fnt<'_>, fat: &[FileAlloc], rom: &'a Rom<'_>, ) -> Result<Self, FileParseError>

Parses an FNT, FAT and ROM to create a FileSystem.

Errors

This function will return an error if raw::Rom::num_arm9_overlays or raw::Rom::num_arm7_overlays fails, or if a file or directory ID is missing from the FNT.

pub fn build_fnt(&self) -> Result<Fnt<'_>, FileBuildError>

Builds an FNT from this FileSystem.

Errors

This function will return an error if a file/directory name contains non-ASCII characters.

pub fn sort_for_fnt(&mut self)

Sorts the entire FileSystem so that it’s laid out in the right order for the FNT.

pub fn sort_for_rom(&mut self)

Sorts the entire FileSystem so that files laid out in the right order for appending to the ROM.

pub fn traverse_files<I, Cb>(&self, path_order: I, callback: Cb)
where I: IntoIterator<Item = &'a str>, Cb: FnMut(&File<'_>, &Path),

Traverses the FileSystem and calls callback for each file found. The directories will be prioritized according to the path_order.

pub fn max_file_id(&self) -> u16

Returns the max file ID of this FileSystem.

pub fn display(&self, indent: usize) -> DisplayFileSystem<'_>

Creates a DisplayFileSystem which implements Display.

pub fn compute_path_order(&self) -> Vec<String>

Computes the path order that the FileSystem is currently in. This can be saved and reused in Self::traverse_files to traverse in the same order later.