ds_rom::rom

Struct Header

source
pub struct Header {
    pub original: HeaderOriginal,
    pub ds_post_dsi: Option<HeaderDsPostDsi>,
}
ROM header.

Fields

original: HeaderOriginal

Values for the original header version, HeaderVersion::Original.

ds_post_dsi: Option<HeaderDsPostDsi>

Values for DS games after DSi release, HeaderVersion::DsPostDsi.

Implementations

source

impl Header

source

pub fn load_raw(header: &Header) -> Self

Loads from a raw header.

source

pub fn build( &self, context: &BuildContext<'_>, rom: &Rom<'_>, ) -> Result<Header, HeaderBuildError>

Builds a raw header.

Panics

Panics if a value is missing in the context.

Errors

This function will return an error if the title contains a non-ASCII character.

source

pub fn version(&self) -> HeaderVersion

Returns the version of this Header.