Struct Logo

pub struct Logo { /* private fields */ }
Header logo.

Implementations

pub fn save_png<P: AsRef<Path>>(&self, path: P) -> Result<(), LogoSaveError>

Saves this Logo to a PNG image.

Errors

This function will return an error if GrayImage::save fails.

pub fn from_png<P: AsRef<Path>>(path: P) -> Result<Self, LogoLoadError>

Loads a Logo from a PNG image.

Errors

This function will return an error if it failed to open or decode the image, or the image has the wrong size or colors.

pub fn decompress(data: &[u8]) -> Result<Self, LogoError>

Decompresses a Logo from a compressed logo in the ROM header.

Errors

This function will return an error if the compressed logo yields an invalid header, footer or bitmap size.

pub fn compress(&self) -> [u8; 156]

Compresses this Logo to put into a ROM header.

pub fn get_pixel(&self, x: usize, y: usize) -> bool

Returns the pixel value at the given coordinates.

pub fn set_pixel(&mut self, x: usize, y: usize, value: bool)

Sets the pixel value at the given coordinates.