Overlay

Struct Overlay 

pub struct Overlay<'a> { /* private fields */ }
An overlay module for ARM9/ARM7.

Implementations

Source

impl<'a> Overlay<'a>

pub fn new<T: Into<Cow<'a, [u8]>>>( data: T, options: OverlayOptions, ) -> Result<Self, OverlayError>

Creates a new Overlay from plain data.

pub fn parse_arm9( overlay: &Overlay, rom: &'a Rom<'_>, arm9: &Arm9<'_>, ) -> Result<Self, OverlayError>

Parses an ARM9 Overlay from a ROM.

Errors

This function will return an error if the overlay is signed and the ARM9 program does not contain overlay signatures.

pub fn parse_arm7( overlay: &Overlay, rom: &'a Rom<'_>, ) -> Result<Self, OverlayError>

Parses an ARM7 Overlay from a ROM.

Errors

This function will return an error if the overlay is signed, as ARM7 overlay signatures are not supported.

pub fn build(&self) -> Overlay

Builds a raw overlay table entry.

pub fn id(&self) -> u16

Returns the ID of this Overlay.

pub fn base_address(&self) -> u32

Returns the base address of this Overlay.

pub fn end_address(&self) -> u32

Returns the end address of this Overlay.

pub fn code_size(&self) -> u32

Returns the size of initialized data in this Overlay.

pub fn bss_size(&self) -> u32

Returns the size of uninitialized data in this Overlay.

pub fn ctor_start(&self) -> u32

Returns the offset to the start of the .ctor section.

pub fn ctor_end(&self) -> u32

Returns the offset to the end of the .ctor section.

pub fn file_id(&self) -> u32

Returns the file ID of this Overlay.

pub fn is_compressed(&self) -> bool

Returns whether this Overlay is compressed. See Self::originally_compressed for whether this overlay was compressed originally.

pub fn is_signed(&self) -> bool

Returns whether this Overlay has a signature.

pub fn decompress(&mut self) -> Result<(), Lz77DecompressError>

Decompresses this Overlay, but does nothing if already decompressed.

pub fn compress(&mut self) -> Result<(), Error>

Compresses this Overlay, but does nothing if already compressed.

Errors

This function will return an error if an I/O operation fails.

pub fn code(&self) -> &[u8]

Returns a reference to the code of this Overlay.

pub fn full_data(&self) -> &[u8]

Returns a reference to the full data of this Overlay.

pub fn info(&self) -> &OverlayInfo

Returns a reference to the info of this Overlay.

pub fn originally_compressed(&self) -> bool

Returns whether this Overlay was compressed originally. See Self::is_compressed for the current state.

pub fn compute_signature( &self, hmac_sha1: &HmacSha1, ) -> Result<HmacSha1Signature, OverlayError>

Computes the signature of this Overlay using the given HMAC-SHA1 key.

pub fn signature(&self) -> Option<HmacSha1Signature>

Returns the signature of this Overlay, if it exists.

pub fn verify_signature( &self, hmac_sha1: &HmacSha1, ) -> Result<bool, OverlayError>

Verifies the signature of this Overlay using the given HMAC-SHA1 key.

pub fn sign(&mut self, hmac_sha1: &HmacSha1) -> Result<(), OverlayError>

Signs this Overlay using the given HMAC-SHA1 key.