pub struct OverlayTableConfig {
pub table_signed: bool,
pub table_signature: Option<HmacSha1Signature>,
pub overlays: Vec<OverlayConfig>,
}Expand description
Configuration for the overlay table, used for both ARM9 and ARM7 overlays.
Fields
table_signed: boolWhether the overlay table has an HMAC-SHA1 signature.
table_signature: Option<HmacSha1Signature>Overlay table HMAC-SHA1 signature. NOTE: This field is temporary! A bug in the DS standard library causes this signature to be computed incorrectly, and we haven’t replicated this bug in our code yet.
overlays: Vec<OverlayConfig>List of overlays.