pub enum RomSaveError {
Show 17 variants
BlowfishKeyNeeded,
Io {
source: Error,
},
File {
source: FileError,
},
SerdeJson {
source: Error,
},
LogoSave {
source: LogoSaveError,
},
LogoLoad {
source: LogoLoadError,
},
RawBuildInfo {
source: RawBuildInfoError,
},
Arm9 {
source: Arm9Error,
},
Arm9Autoload {
source: Arm9AutoloadError,
},
BannerImage {
source: BannerImageError,
},
Lz77Decompress {
source: Lz77DecompressError,
},
Overlay {
source: OverlayError,
},
HmacSha1FromBytes {
source: HmacSha1FromBytesError,
},
Arm9HmacSha1Key {
source: Arm9HmacSha1KeyError,
},
Arm9OverlaySignatures {
source: Arm9OverlaySignaturesError,
},
NoHmacSha1Key {
backtrace: Backtrace,
},
AutoloadNotFound {
index: u32,
backtrace: Backtrace,
},
}Variants
BlowfishKeyNeeded
Occurs when the ROM is encrypted but no Blowfish key was provided.
Io
See io::Error.
File
See [FileError].
Fields

source: FileErrorSource error.
SerdeJson
See serde_yml::Error.
LogoSave
See LogoSaveError.
Fields

source: LogoSaveErrorSource error.
LogoLoad
See LogoLoadError.
Fields

source: LogoLoadErrorSource error.
RawBuildInfo
See RawBuildInfoError.
Fields

source: RawBuildInfoErrorSource error.
Arm9
See Arm9Error.
Arm9Autoload
See Arm9AutoloadError.
Fields

source: Arm9AutoloadErrorSource error.
BannerImage
See BannerImageError.
Fields

source: BannerImageErrorSource error.
Lz77Decompress
See Lz77DecompressError.
Fields

source: Lz77DecompressErrorSource error.
Overlay
See OverlayError.
Fields

source: OverlayErrorSource error.
HmacSha1FromBytes
Fields

source: HmacSha1FromBytesErrorSource error.
Arm9HmacSha1Key
See Arm9HmacSha1KeyError.
Fields

source: Arm9HmacSha1KeyErrorSource error.
Arm9OverlaySignatures
Fields

source: Arm9OverlaySignaturesErrorSource error.
NoHmacSha1Key
Occurs when the HMAC-SHA1 key was not provided for a signed overlay.
AutoloadNotFound
Occurs when an autoload was not found in the config.