pub struct BannerKeyframe(/* private fields */);Expand description
A keyframe for BannerAnimation.
Implementations
sourceimpl BannerKeyframe
impl BannerKeyframe
sourcepub const fn frame_duration(&self) -> u8
pub const fn frame_duration(&self) -> u8
How long to show this keyframe for, in frames.
Bits: 0..8
sourcepub const fn with_frame_duration(self, value: u8) -> Self
pub const fn with_frame_duration(self, value: u8) -> Self
How long to show this keyframe for, in frames.
Bits: 0..8
sourcepub fn set_frame_duration(&mut self, value: u8)
pub fn set_frame_duration(&mut self, value: u8)
How long to show this keyframe for, in frames.
Bits: 0..8
sourcepub const fn bitmap_index(&self) -> u8
pub const fn bitmap_index(&self) -> u8
Which of the 8 bitmaps to show.
Bits: 8..11
sourcepub const fn with_bitmap_index(self, value: u8) -> Self
pub const fn with_bitmap_index(self, value: u8) -> Self
Which of the 8 bitmaps to show.
Bits: 8..11
sourcepub fn set_bitmap_index(&mut self, value: u8)
pub fn set_bitmap_index(&mut self, value: u8)
Which of the 8 bitmaps to show.
Bits: 8..11
sourcepub const fn palette_index(&self) -> u8
pub const fn palette_index(&self) -> u8
Which of the 8 palettes to use.
Bits: 11..14
sourcepub const fn with_palette_index(self, value: u8) -> Self
pub const fn with_palette_index(self, value: u8) -> Self
Which of the 8 palettes to use.
Bits: 11..14
sourcepub fn set_palette_index(&mut self, value: u8)
pub fn set_palette_index(&mut self, value: u8)
Which of the 8 palettes to use.
Bits: 11..14
sourcepub const fn flip_horizontally(&self) -> bool
pub const fn flip_horizontally(&self) -> bool
Flips the bitmap horizontally.
Bits: 14..15
sourcepub const fn with_flip_horizontally(self, value: bool) -> Self
pub const fn with_flip_horizontally(self, value: bool) -> Self
Flips the bitmap horizontally.
Bits: 14..15
sourcepub fn set_flip_horizontally(&mut self, value: bool)
pub fn set_flip_horizontally(&mut self, value: bool)
Flips the bitmap horizontally.
Bits: 14..15
sourcepub const fn flip_vertically(&self) -> bool
pub const fn flip_vertically(&self) -> bool
Flips the bitmap vertically.
Bits: 15..16
sourcepub const fn with_flip_vertically(self, value: bool) -> Self
pub const fn with_flip_vertically(self, value: bool) -> Self
Flips the bitmap vertically.
Bits: 15..16
sourcepub fn set_flip_vertically(&mut self, value: bool)
pub fn set_flip_vertically(&mut self, value: bool)
Flips the bitmap vertically.
Bits: 15..16