pub struct Fnt<'a> {
pub subtables: Box<[FntSubtable<'a>]>,
}Expand description
File Name Table or FNT for short. Contains the names of every file and directory in the ROM. This is the raw struct, see the plain one here.
Fields
subtables: Box<[FntSubtable<'a>]>Every directory has one subtable, indexed by dir_id & 0xfff
Implementations
Sourceimpl<'a> Fnt<'a>
impl<'a> Fnt<'a>
Sourcepub fn borrow_from_slice(data: &'a [u8]) -> Result<Self, RawFntError>
pub fn borrow_from_slice(data: &'a [u8]) -> Result<Self, RawFntError>