#[repr(C)]pub struct FntDirectory {
pub subtable_offset: u32,
pub first_file_id: u16,
pub parent_id: u16,
}Expand description
A directory entry in the FNT’s directory list.
Fields
subtable_offset: u32Offset to this directory’s subtable, which contains the names of immediate children (both files and directories).
first_file_id: u16The first file ID.
parent_id: u16The parent ID. If this is the root directory, this number is actually the total number of directories, as the root has no parent anyway.