pub struct BannerImages {
pub bitmap: BannerBitmap,
pub palette: BannerPalette,
pub animation_bitmaps: Option<Box<[BannerBitmap]>>,
pub animation_palettes: Option<Box<[BannerPalette]>>,
pub bitmap_path: PathBuf,
pub palette_path: PathBuf,
}Expand description
Icon for the Banner.
Fields
bitmap: BannerBitmapMain bitmap.
palette: BannerPaletteMain palette.
animation_bitmaps: Option<Box<[BannerBitmap]>>Bitmaps for animated icon.
animation_palettes: Option<Box<[BannerPalette]>>Palettes for animated icon
bitmap_path: PathBufPath to bitmap PNG.
palette_path: PathBufPath to palette PNG.
Implementations
sourceimpl BannerImages
impl BannerImages
sourcepub fn from_bitmap(bitmap: BannerBitmap, palette: BannerPalette) -> Self
pub fn from_bitmap(bitmap: BannerBitmap, palette: BannerPalette) -> Self
Creates a new BannerImages from a bitmap and palette.
sourcepub fn load(&mut self, path: &Path) -> Result<(), BannerImageError>
pub fn load(&mut self, path: &Path) -> Result<(), BannerImageError>
Loads the bitmap and palette
Errors
This function will return an error if Reader::open or Reader::decode fails, or if the images are the wrong
size, or the bitmap has a color not present in the palette.
sourcepub fn save_bitmap_file(&self, path: &Path) -> Result<(), BannerImageError>
pub fn save_bitmap_file(&self, path: &Path) -> Result<(), BannerImageError>