Struct ds_rom::rom::BannerImages
source · pub struct BannerImages {
pub bitmap: BannerBitmap,
pub palette: BannerPalette,
pub animation_bitmaps: Option<Box<[BannerBitmap]>>,
pub animation_palettes: Option<Box<[BannerPalette]>>,
}Expand description
Icon for the Banner.
Fields
bitmap: BannerBitmapMain bitmap.
palette: BannerPaletteMain palette.
animation_bitmaps: Option<Box<[BannerBitmap]>>Bitmaps for animated icon.
animation_palettes: Option<Box<[BannerPalette]>>Palettes for animated icon
Implementations
sourceimpl BannerImages
impl BannerImages
sourcepub fn from_bitmap(bitmap: BannerBitmap, palette: BannerPalette) -> Self
pub fn from_bitmap(bitmap: BannerBitmap, palette: BannerPalette) -> Self
Creates a new BannerImages from a bitmap and palette.
sourcepub fn load_bitmap_file<P: AsRef<Path> + Into<PathBuf>>(
&mut self,
bitmap_path: P,
palette_path: P,
) -> Result<(), BannerImageError>
pub fn load_bitmap_file<P: AsRef<Path> + Into<PathBuf>>( &mut self, bitmap_path: P, palette_path: P, ) -> Result<(), BannerImageError>
Loads from a bitmap and palette file.
Errors
This function will return an error if Reader::open or Reader::decode fails, or if the images are the wrong
size, or the bitmap has a color not present in the palette.
sourcepub fn save_bitmap_file(&self, path: &Path) -> Result<(), BannerImageError>
pub fn save_bitmap_file(&self, path: &Path) -> Result<(), BannerImageError>