Struct ds_rom::rom::BannerImages

source ·
pub struct BannerImages {
    pub bitmap: BannerBitmap,
    pub palette: BannerPalette,
    pub animation_bitmaps: Option<Box<[BannerBitmap]>>,
    pub animation_palettes: Option<Box<[BannerPalette]>>,
}
Icon for the Banner.

Fields

bitmap: BannerBitmap

Main bitmap.

palette: BannerPalette

Main palette.

animation_bitmaps: Option<Box<[BannerBitmap]>>

Bitmaps for animated icon.

animation_palettes: Option<Box<[BannerPalette]>>

Palettes for animated icon

Implementations

source

impl BannerImages

source

pub fn from_bitmap(bitmap: BannerBitmap, palette: BannerPalette) -> Self

Creates a new BannerImages from a bitmap and palette.

source

pub fn load_bitmap_file<P: AsRef<Path> + Into<PathBuf>>( &mut self, bitmap_path: P, palette_path: P, ) -> Result<(), BannerImageError>

Loads from a bitmap and palette file.

Errors

This function will return an error if Reader::open or Reader::decode fails, or if the images are the wrong size, or the bitmap has a color not present in the palette.

source

pub fn save_bitmap_file(&self, path: &Path) -> Result<(), BannerImageError>

Saves to a bitmap and palette file in the given path.

Errors

See RgbImage::save.