Struct ds_rom::rom::Overlay

source ·
pub struct Overlay<'a> { /* private fields */ }
An overlay module for ARM9/ARM7.

Implementations

source

impl<'a> Overlay<'a>

source

pub fn new<T: Into<Cow<'a, [u8]>>>( data: T, header_version: HeaderVersion, info: OverlayInfo, ) -> Self

Creates a new Overlay from plain data.

source

pub fn parse( overlay: &Overlay, fat: &[FileAlloc], rom: &'a Rom<'_>, ) -> Result<Self, RawHeaderError>

Parses an Overlay from a FAT and ROM.

source

pub fn build(&self) -> Overlay

Builds a raw overlay table entry.

source

pub fn id(&self) -> u32

Returns the ID of this Overlay.

source

pub fn base_address(&self) -> u32

Returns the base address of this Overlay.

source

pub fn code_size(&self) -> u32

Returns the size of initialized data in this Overlay.

source

pub fn bss_size(&self) -> u32

Returns the size of uninitialized data in this Overlay.

source

pub fn ctor_start(&self) -> u32

Returns the offset to the start of the .ctor section.

source

pub fn ctor_end(&self) -> u32

Returns the offset to the end of the .ctor section.

source

pub fn file_id(&self) -> u32

Returns the file ID of this Overlay.

source

pub fn is_compressed(&self) -> bool

Returns whether this Overlay is compressed.

source

pub fn decompress(&mut self)

Decompresses this Overlay, but does nothing if already decompressed.

source

pub fn compress(&mut self) -> Result<(), Error>

Compresses this Overlay, but does nothing if already compressed.

Errors

This function will return an error if an I/O operation fails.

source

pub fn code(&self) -> &[u8]

Returns a reference to the code of this Overlay.

source

pub fn full_data(&self) -> &[u8]

Returns a reference to the full data of this Overlay.

source

pub fn info(&self) -> &OverlayInfo

Returns a reference to the info of this Overlay.