pub struct Overlay<'a> { /* private fields */ }Expand description
An overlay module for ARM9/ARM7.
Implementations
sourceimpl<'a> Overlay<'a>
impl<'a> Overlay<'a>
sourcepub fn new<T: Into<Cow<'a, [u8]>>>(
data: T,
header_version: HeaderVersion,
info: OverlayInfo,
) -> Self
pub fn new<T: Into<Cow<'a, [u8]>>>( data: T, header_version: HeaderVersion, info: OverlayInfo, ) -> Self
Creates a new Overlay from plain data.
sourcepub fn parse(
overlay: &Overlay,
fat: &[FileAlloc],
rom: &'a Rom<'_>,
) -> Result<Self, RawHeaderError>
pub fn parse( overlay: &Overlay, fat: &[FileAlloc], rom: &'a Rom<'_>, ) -> Result<Self, RawHeaderError>
Parses an Overlay from a FAT and ROM.
sourcepub fn base_address(&self) -> u32
pub fn base_address(&self) -> u32
Returns the base address of this Overlay.
sourcepub fn ctor_start(&self) -> u32
pub fn ctor_start(&self) -> u32
Returns the offset to the start of the .ctor section.
sourcepub fn is_compressed(&self) -> bool
pub fn is_compressed(&self) -> bool
Returns whether this Overlay is compressed.
sourcepub fn decompress(&mut self)
pub fn decompress(&mut self)
Decompresses this Overlay, but does nothing if already decompressed.
sourcepub fn info(&self) -> &OverlayInfo
pub fn info(&self) -> &OverlayInfo
Returns a reference to the info of this Overlay.