OverlayTable

Struct OverlayTable 

pub struct OverlayTable<'a> { /* private fields */ }
An overlay table, used for both ARM9 and ARM7 overlays. This is the plain struct, see the raw one here.

Implementations

Source

impl<'a> OverlayTable<'a>

pub fn new(overlays: Vec<Overlay<'a>>) -> Self

Creates a new OverlayTable.

pub fn overlays(&self) -> &[Overlay<'a>]

Returns a reference to the overlays of this OverlayTable.

pub fn overlays_mut(&mut self) -> &mut [Overlay<'a>]

Returns a mutable reference to the overlays of this OverlayTable.

pub fn len(&self) -> usize

Returns the length of this OverlayTable.

pub fn is_empty(&self) -> bool

Returns true if this OverlayTable is empty.

pub fn parse_arm9( raw: OverlayTable<'_>, rom: &'a Rom<'_>, arm9: &Arm9<'_>, ) -> Result<Self, OverlayError>

Parses an OverlayTable from the given raw ARM9 overlay table.

Errors

See Overlay::parse_arm9.

pub fn parse_arm7( raw: OverlayTable<'_>, rom: &'a Rom<'_>, ) -> Result<Self, OverlayError>

Parses an OverlayTable from the given raw ARM7 overlay table.

Errors

See Overlay::parse_arm7.

pub fn build(&self) -> OverlayTable<'a>

Builds a raw overlay table.

pub fn compute_signature(&self, hmac_sha1: &HmacSha1) -> HmacSha1Signature

Computes the HMAC-SHA1 signature of this overlay table using the given HMAC-SHA1 instance.

pub fn verify_signature(&self, hmac_sha1: &HmacSha1) -> bool

Verifies the HMAC-SHA1 signature of this overlay table using the given HMAC-SHA1 instance.

pub fn signature(&self) -> Option<HmacSha1Signature>

Returns the HMAC-SHA1 signature of this overlay table, if it exists.

pub fn sign(&mut self, hmac_sha1: &HmacSha1)

Computes and sets the HMAC-SHA1 signature of this overlay table.

pub fn is_signed(&self) -> bool

Returns true if this overlay table has an HMAC-SHA1 signature.

pub fn set_signature(&mut self, signature: HmacSha1Signature)

Sets the signature of this overlay table.