Struct ds_rom::rom::Rom

source ·
pub struct Rom<'a> { /* private fields */ }
A plain ROM.

Implementations

source

impl<'a> Rom<'a>

source

pub fn load<P: AsRef<Path>>( path: P, options: RomLoadOptions<'_>, ) -> Result<Self, RomSaveError>

Loads a ROM from a path generated by Self::save.

Errors

This function will return an error if there’s a file missing or the file has an invalid format.

source

pub fn save<P: AsRef<Path>>( &self, path: P, key: Option<&BlowfishKey>, ) -> Result<(), RomSaveError>

Saves this ROM to a path as separate files.

Errors

This function will return an error if a file could not be created or the a component of the ROM has an invalid format.

source

pub fn extract(rom: &'a Rom<'_>) -> Result<Self, RomExtractError>

Extracts from a raw ROM.

Errors

This function will return an error if a component is missing from the raw ROM.

source

pub fn build(self, key: Option<&BlowfishKey>) -> Result<Rom<'a>, RomBuildError>

Builds a raw ROM.

Errors

This function will return an error if an I/O operation fails or a component fails to build.

Returns a reference to the header logo of this Rom.

source

pub fn arm9(&self) -> &Arm9<'_>

Returns a reference to the ARM9 program of this Rom.

source

pub fn arm9_overlays(&self) -> &[Overlay<'_>]

Returns a reference to the ARM9 overlays of this Rom.

source

pub fn arm7(&self) -> &Arm7<'_>

Returns a reference to the ARM7 program of this Rom.

source

pub fn arm7_overlays(&self) -> &[Overlay<'_>]

Returns a reference to the ARM7 overlays of this Rom.

source

pub fn header(&self) -> &Header

Returns a reference to the header of this Rom.